@@ -50,6 +50,8 @@
  * giomm (part of the glibmm project) also contains:
  * - Asynchronous IO. See Gio::File and the @ref Streams.
  * - @ref NetworkIO
+ * - @ref DBus
+ * - Gio::Settings for application settings.
  *
  * @section basics Basic Usage
  *
@@ -79,6 +81,11 @@
 
 #include <glibmmconfig.h>
 //#include <glibmm/i18n.h> //This must be included by the application, after system headers such as <iostream>.
+
+//Include this first because we need it to be the first thing to include <glib.h>, 
+//so we can do an undef trick to still use deprecated API in the header: 
+#include <glibmm/thread.h>
+
 #include <glibmm/arrayhandle.h>
 #include <glibmm/balancedtree.h>
 #include <glibmm/checksum.h>
@@ -120,7 +127,6 @@
 #include <glibmm/slisthandle.h>
 #include <glibmm/spawn.h>
 #include <glibmm/stringutils.h>
-#include <glibmm/thread.h>
 #include <glibmm/threadpool.h>
 #include <glibmm/timer.h>
 #include <glibmm/timeval.h>
@@ -131,6 +137,7 @@
 #include <glibmm/variant.h>
 #include <glibmm/variantiter.h>
 #include <glibmm/varianttype.h>
+#include <glibmm/vectorutils.h>
 #include <glibmm/wrap.h>
 
 #endif /* _GLIBMM_H */
