@@ -18,10 +18,12 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <glibmm/thread.h>
+
 #undef G_DISABLE_DEPRECATED //So we can use newly-deprecated API, to preserve our API.
+
 #include <glibmm/main.h>
 #include <glibmm/exceptionhandler.h>
-#include <glibmm/thread.h>
 #include <glibmm/wrap.h>
 #include <glibmm/iochannel.h>
 #include <algorithm>
@@ -62,7 +64,7 @@ void* SourceConnectionNode::notify(void* data)
   // because we set self->source_ to 0 there:
   if (self->source_)
   {
-    GSource* s = self->source_;  
+    GSource* s = self->source_;
     self->source_ = 0;
     g_source_destroy(s);
 
@@ -295,7 +297,7 @@ sigc::connection SignalTimeout::connect(const sigc::slot<bool>& slot,
   return connection;
 }
 
-void SignalTimeout::connect_once(const sigc::slot<void>& slot, 
+void SignalTimeout::connect_once(const sigc::slot<void>& slot,
                                  unsigned int interval, int priority)
 {
     connect(sigc::bind_return(slot, false), interval, priority);
@@ -324,7 +326,7 @@ sigc::connection SignalTimeout::connect_seconds(const sigc::slot<bool>& slot,
   return connection;
 }
 
-void SignalTimeout::connect_seconds_once(const sigc::slot<void>& slot, 
+void SignalTimeout::connect_seconds_once(const sigc::slot<void>& slot,
                                          unsigned int interval, int priority)
 {
     connect_seconds(sigc::bind_return(slot, false), interval, priority);
@@ -435,7 +437,7 @@ sigc::connection SignalChildWatch::connect(const sigc::slot<void, GPid, int>& sl
   const sigc::connection connection(*conn_node->get_slot());
 
   GSource *const source = g_child_watch_source_new(pid);
- 
+
   if(priority != G_PRIORITY_DEFAULT)
     g_source_set_priority(source, priority);
 
@@ -653,7 +655,7 @@ Glib::RefPtr<MainContext> MainLoop::get_context()
 int MainLoop::depth()
 {
   return g_main_depth();
-}                                             
+}
 
 void MainLoop::reference() const
 {
@@ -834,12 +836,11 @@ void Source::get_current_time(Glib::TimeVal& current_time)
 }
 #endif //GLIBMM_DISABLE_DEPRECATED
 
-void Source::get_time(TimeSpec& timespec)
+gint64 Source::get_time() const
 {
-  g_source_get_time(gobject_, &timespec);
+  return g_source_get_time(const_cast<GSource*>(gobject_));
 }
 
-
 inline // static
 Source* Source::get_wrapper(GSource* source)
 {
@@ -1088,4 +1089,3 @@ bool IOSource::dispatch(sigc::slot_base* slot)
 }
 
 } // namespace Glib
-
