@@ -23,8 +23,8 @@
 #include <glibmm/refptr.h>
 #include <glibmm/timeval.h>
 #include <glibmm/priorities.h>
+#include <glibmm/iochannel.h>
 #include <sigc++/sigc++.h>
-#include <glib.h>
 #include <vector>
 
 namespace Glib
@@ -32,66 +32,12 @@ namespace Glib
 
 class Cond;
 class Mutex;
-class IOChannel;
-
-typedef GTimeSpec TimeSpec; //TODO: Really wrap this?
 
 /** @defgroup MainLoop The Main Event Loop
  * Manages all available sources of events.
  * @{
  */
 
-/** A bitwise combination representing an I/O condition to watch for on an
- * event source.
- * The flags correspond to those used by the <tt>%poll()</tt> system call
- * on UNIX (see <tt>man 2 poll</tt>).  To test for individual flags, do
- * something like this:
- * @code
- * if((condition & Glib::IO_OUT) != 0)
- *   do_some_output();
- * @endcode
- * @par Bitwise operators:
- * <tt>IOCondition operator|(IOCondition, IOCondition)</tt><br>
- * <tt>IOCondition operator&(IOCondition, IOCondition)</tt><br>
- * <tt>IOCondition operator^(IOCondition, IOCondition)</tt><br>
- * <tt>IOCondition operator~(IOCondition)</tt><br>
- * <tt>IOCondition& operator|=(IOCondition&, IOCondition)</tt><br>
- * <tt>IOCondition& operator&=(IOCondition&, IOCondition)</tt><br>
- * <tt>IOCondition& operator^=(IOCondition&, IOCondition)</tt><br>
- */
-enum IOCondition
-{
-  IO_IN   = G_IO_IN,  /*!< @hideinitializer There is data to read. */
-  IO_OUT  = G_IO_OUT, /*!< @hideinitializer Data can be written (without blocking). */
-  IO_PRI  = G_IO_PRI, /*!< @hideinitializer There is urgent data to read. */
-  IO_ERR  = G_IO_ERR, /*!< @hideinitializer %Error condition. */
-  IO_HUP  = G_IO_HUP, /*!< @hideinitializer Hung up (the connection has been broken,
-                                            usually for pipes and sockets). */
-  IO_NVAL = G_IO_NVAL /*!< @hideinitializer Invalid request. The file descriptor is not open. */
-};
-
-inline IOCondition operator|(IOCondition lhs, IOCondition rhs)
-  { return static_cast<IOCondition>(static_cast<unsigned>(lhs) | static_cast<unsigned>(rhs)); }
-
-inline IOCondition operator&(IOCondition lhs, IOCondition rhs)
-  { return static_cast<IOCondition>(static_cast<unsigned>(lhs) & static_cast<unsigned>(rhs)); }
-
-inline IOCondition operator^(IOCondition lhs, IOCondition rhs)
-  { return static_cast<IOCondition>(static_cast<unsigned>(lhs) ^ static_cast<unsigned>(rhs)); }
-
-inline IOCondition operator~(IOCondition flags)
-  { return static_cast<IOCondition>(~static_cast<unsigned>(flags)); }
-
-inline IOCondition& operator|=(IOCondition& lhs, IOCondition rhs)
-  { return (lhs = static_cast<IOCondition>(static_cast<unsigned>(lhs) | static_cast<unsigned>(rhs))); }
-
-inline IOCondition& operator&=(IOCondition& lhs, IOCondition rhs)
-  { return (lhs = static_cast<IOCondition>(static_cast<unsigned>(lhs) & static_cast<unsigned>(rhs))); }
-
-inline IOCondition& operator^=(IOCondition& lhs, IOCondition rhs)
-  { return (lhs = static_cast<IOCondition>(static_cast<unsigned>(lhs) ^ static_cast<unsigned>(rhs))); }
-
-
 class PollFD
 {
 public:
@@ -163,7 +109,7 @@ public:
   * void on_timeout_once()
   * @endcode
   * @param interval The timeout in milliseconds.
-  * @param priority The priority of the new event source. 
+  * @param priority The priority of the new event source.
   */
   void connect_once(const sigc::slot<void>& slot, unsigned int interval,
                     int priority = PRIORITY_DEFAULT);
@@ -210,7 +156,7 @@ public:
   * void on_timeout_once()
   * @endcode
   * @param interval The timeout in milliseconds.
-  * @param priority The priority of the new event source. 
+  * @param priority The priority of the new event source.
   */
   void connect_seconds_once(const sigc::slot<void>& slot, unsigned int interval,
                             int priority = PRIORITY_DEFAULT);
@@ -331,7 +277,7 @@ public:
    * @param priority The priority of the new event source.
    * @return A connection handle, which can be used to disconnect the handler.
    */
-  sigc::connection connect(const sigc::slot<void,GPid, int>& slot, GPid pid, 
+  sigc::connection connect(const sigc::slot<void,GPid, int>& slot, GPid pid,
 int priority = PRIORITY_DEFAULT);
 private:
   GMainContext* context_;
@@ -373,16 +319,16 @@ public:
    * @return The new MainContext.
    */
   static Glib::RefPtr<MainContext> create();
-  /** Returns the default main context. 
+  /** Returns the default main context.
    * This is the main context used for main loop functions when a main loop is not explicitly specified.
    * @return The new MainContext.
    */
   static Glib::RefPtr<MainContext> get_default();
 
-  /** Runs a single iteration for the given main loop. 
-   * This involves checking to see if any event sources are ready to be processed, then if no events sources are 
-   * ready and may_block is true, waiting for a source to become ready, then dispatching the highest priority events 
-   * sources that are ready. Note that even when may_block is true, it is still possible for iteration() to return 
+  /** Runs a single iteration for the given main loop.
+   * This involves checking to see if any event sources are ready to be processed, then if no events sources are
+   * ready and may_block is true, waiting for a source to become ready, then dispatching the highest priority events
+   * sources that are ready. Note that even when may_block is true, it is still possible for iteration() to return
    * false, since the the wait may be interrupted for other reasons than an event source becoming ready.
    * @param may_block Whether the call may block.
    * @return true if events were dispatched.
@@ -398,9 +344,9 @@ public:
    */
   void wakeup();
 
-  /** Tries to become the owner of the specified context. 
-   * If some other context is the owner of the context, returns FALSE immediately. Ownership is properly recursive: 
-   * the owner can require ownership again and will release ownership when release() is called as many times as 
+  /** Tries to become the owner of the specified context.
+   * If some other context is the owner of the context, returns FALSE immediately. Ownership is properly recursive:
+   * the owner can require ownership again and will release ownership when release() is called as many times as
    * acquire().
    * You must be the owner of a context before you can call prepare(), query(), check(), dispatch().
    * @return true if the operation succeeded, and this thread is now the owner of context.
@@ -408,8 +354,8 @@ public:
   bool acquire();
 
 
-  /** Tries to become the owner of the specified context, as with acquire(). But if another thread is the owner, 
-   * atomically drop mutex and wait on cond until that owner releases ownership or until cond is signaled, then try 
+  /** Tries to become the owner of the specified context, as with acquire(). But if another thread is the owner,
+   * atomically drop mutex and wait on cond until that owner releases ownership or until cond is signaled, then try
    * again (once) to become the owner.
    * @param cond A condition variable.
    * @param mutex A mutex, currently held.
@@ -417,7 +363,7 @@ public:
    */
   bool wait(Glib::Cond& cond, Glib::Mutex& mutex);
 
-  /** Releases ownership of a context previously acquired by this thread with acquire(). If the context was acquired 
+  /** Releases ownership of a context previously acquired by this thread with acquire(). If the context was acquired
    * multiple times, the only release ownership when release() is called as many times as it was acquired.
    */
   void release();
@@ -470,7 +416,7 @@ public:
    * @param priority The priority for this file descriptor which should be the same as the priority used for Glib::Source::attach() to ensure that the file descriptor is polled whenever the results may be needed.
    */
   void add_poll(PollFD& fd, int priority);
-  
+
   /** Removes file descriptor from the set of file descriptors to be polled for a particular context.
    * @param fd A PollFD structure holding information about a file descriptor.
    */
@@ -528,7 +474,7 @@ public:
   static Glib::RefPtr<MainLoop> create(const Glib::RefPtr<MainContext>& context,
                                        bool is_running = false);
 
-  /** Runs a main loop until quit() is called on the loop. 
+  /** Runs a main loop until quit() is called on the loop.
    * If this is called for the thread of the loop's MainContext, it will process events from the loop, otherwise it will simply wait.
    */
   void run();
@@ -554,7 +500,7 @@ public:
    */
   void reference()   const;
 
-  /** Decreases the reference count on a MainLoop object by one. 
+  /** Decreases the reference count on a MainLoop object by one.
    * If the result is zero, free the loop and free all associated memory.
    */
   void unreference() const;
@@ -597,8 +543,8 @@ public:
   unsigned int attach();
 
   //TODO: Does this destroy step make sense in C++? Should it just be something that happens in a destructor?
-  
-  /** Removes a source from its MainContext, if any, and marks it as destroyed. 
+
+  /** Removes a source from its MainContext, if any, and marks it as destroyed.
    * The source cannot be subsequently added to another context.
    */
   void destroy();
@@ -607,33 +553,33 @@ public:
    * @param priority The new priority.
    */
   void set_priority(int priority);
-  
+
   /** Gets the priority of a source.
    * @return The priority of the source.
    */
   int  get_priority() const;
 
-  /** Sets whether a source can be called recursively. 
+  /** Sets whether a source can be called recursively.
    * If @a can_recurse is true, then while the source is being dispatched then this source will be processed normally. Otherwise, all processing of this source is blocked until the dispatch function returns.
    * @param can_recurse Whether recursion is allowed for this source.
    */
   void set_can_recurse(bool can_recurse);
-  
+
   /** Checks whether a source is allowed to be called recursively. see set_can_recurse().
    * @return Whether recursion is allowed.
    */
   bool get_can_recurse() const;
 
-  /** Returns the numeric ID for a particular source. 
+  /** Returns the numeric ID for a particular source.
    * The ID of a source is unique within a particular main loop context. The reverse mapping from ID to source is done by MainContext::find_source_by_id().
    * @return The ID for the source.
    */
   unsigned int get_id() const;
 
   //TODO: Add a const version of this method?
-  /** Gets the MainContext with which the source is associated. 
+  /** Gets the MainContext with which the source is associated.
    * Calling this function on a destroyed source is an error.
-   * @return The MainContext with which the source is associated, or a null RefPtr if the context has not yet been added to a source. 
+   * @return The MainContext with which the source is associated, or a null RefPtr if the context has not yet been added to a source.
    */
   Glib::RefPtr<MainContext> get_context();
 
@@ -662,14 +608,14 @@ protected:
 
   sigc::connection connect_generic(const sigc::slot_base& slot);
 
-  /** Adds a file descriptor to the set of file descriptors polled for this source. 
+  /** Adds a file descriptor to the set of file descriptors polled for this source.
    * The event source's check function will typically test the revents field in the PollFD  and return true if events need to be processed.
    * @param poll_fd A PollFD object holding information about a file descriptor to watch.
    */
   void add_poll(PollFD& poll_fd);
-  
+
   /** Removes a file descriptor from the set of file descriptors polled for this source.
-   * @param poll_fd A PollFD object previously passed to add_poll(). 
+   * @param poll_fd A PollFD object previously passed to add_poll().
    */
   void remove_poll(PollFD& poll_fd);
 
@@ -691,11 +637,11 @@ protected:
    * The time here is the system monotonic time, if available, or some
    * other reasonable alternative otherwise.  See g_get_monotonic_time().
    *
-   * @param A TimeSpec in which to store the time.
+   * @result The monotonic time in microseconds.
    *
    * @newin{2,28}
    */
-  void get_time(TimeSpec& timespec);
+  gint64 get_time() const;
 
   virtual bool prepare(int& timeout) = 0;
   virtual bool check() = 0;
@@ -742,7 +688,9 @@ protected:
   virtual bool dispatch(sigc::slot_base* slot);
 
 private:
+  //TODO: Replace with gint64, because TimeVal is deprecated, when we can break ABI.
   Glib::TimeVal expiration_;
+
   unsigned int  interval_;
 };
 
@@ -793,4 +741,3 @@ private:
 
 
 #endif /* _GLIBMM_MAIN_H */
-
