@@ -191,7 +191,7 @@ sub extract_token($)
 
     return $_;
    }
-     
+
   return "";
 }
 
@@ -521,7 +521,7 @@ sub on_class($$)
   my @back;
   push(@back, $class_command);
   push(@back, "($str)");
-  
+
   # When we hit _CLASS, we walk backwards through the output to find "class"
   my $token;
   while ( scalar(@{$$objOutputter{out}}))
@@ -624,7 +624,7 @@ sub on_end_class($)
 
 
 ########################################
-###  
+###
 # void on_end_namespace($)
 sub on_end_namespace($)
 {
@@ -682,15 +682,15 @@ sub string_split_commas($)
   my @out;
   my $level = 0;
   my $str = "";
-  my @in = split(/([,()])/, $in);
+  my @in = split(/([,()<>])/, $in);
 
   while ($#in > -1)
     {
       my $t = shift @in;
 
       next if ($t eq "");
-      $level++ if ($t eq "(");
-      $level-- if ($t eq ")");
+      $level++ if ($t eq "(" or $t eq "<");
+      $level-- if ($t eq ")" or $t eq ">");
 
       # skip , inside functions  Ie.  void (*)(int,int)
       if ( ($t eq ",") && !$level) 
@@ -761,9 +761,9 @@ sub read_file($$$)
   #      *.
   #      //
   #      any char proceeded by \
-  #      symbols ;{}"`'()
+  #      symbols ;{}"`'()<>
   #      newline
-  @tokens = split(/(\#[lf] \S+\n)|([#A-Za-z0-9_]+)|(\/\*\*)|(\/\*)|(\*\/)|(\/\/)|(\\.)|([;{}"'`()])|(\n)/,
+  @tokens = split(/(\#[lf] \S+\n)|([#A-Za-z0-9_]+)|(\/\*\*)|(\/\*)|(\*\/)|(\/\/)|(\\.)|([;{}"'`()<>])|(\n)/,
                          $strIn);
 }
 
@@ -894,6 +894,9 @@ sub on_wrap_method($)
   }
 
   # Extra stuff needed?
+  $$objCfunc{rettype_needs_ref} = 0;
+  $$objCfunc{throw_any_errors} = 0;
+  $$objCfunc{constversion} = 0;
   $$objCfunc{deprecated} = "";
   my $deprecation_docs = "";
   my $ifdef;
@@ -984,6 +987,7 @@ sub on_wrap_method_docs_only($)
   }
 
   # Extra ref needed?
+  $$objCfunc{throw_any_errors} = 0;
   while($#args >= 1) # If the optional ref/err arguments are there.
   {
     my $argRef = string_trim(pop @args);
@@ -1059,7 +1063,7 @@ sub on_wrap_ctor($)
 sub on_implements_interface($$)
 {
   my ($self) = @_;
-  
+
   if( !($self->check_for_eof()) )
   {
    return;
@@ -1126,7 +1130,7 @@ sub on_wrap_signal($$)
   my $bCustomCCallback = 0;
   my $bRefreturn = 0;
   my $ifdef;
-  
+
   while($#args >= 2) # If optional arguments are there.
   {
     my $argRef = string_trim(pop @args);
@@ -1149,7 +1153,7 @@ sub on_wrap_signal($$)
     {
       $bRefreturn = 1;
     }
-    
+
   	elsif($argRef =~ /^ifdef(.*)/) #If ifdef is at the start.
     {
     	$ifdef = $1;
@@ -1312,7 +1316,7 @@ sub output_wrap_check($$$$$$)
 sub output_wrap_signal($$$$$$$$$)
 {
   my ($self, $CppDecl, $signal_name, $filename, $line_num, $bCustomDefaultHandler, $bNoDefaultHandler, $bCustomCCallback, $bRefreturn, $ifdef, $merge_doxycomment_with_previous) = @_;
-  
+
   #Some checks:
   return if ($self->output_wrap_check($CppDecl, $signal_name,
                                       $filename, $line_num, "_WRAP_SIGNAL"));
